Mesa (master): egl: EGL_MATCH_NATIVE_NATIVE_PIXMAP cannot be EGL_DONT_CARE

Chia-I Wu olv at kemper.freedesktop.org
Fri Jul 29 01:25:03 UTC 2011


Module: Mesa
Branch: master
Commit: d6a9564854601bd01a1132f0a17fcab1d2a41481
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=d6a9564854601bd01a1132f0a17fcab1d2a41481

Author: Chia-I Wu <olv at lunarg.com>
Date:   Thu Jul 28 16:03:11 2011 +0900

egl: EGL_MATCH_NATIVE_NATIVE_PIXMAP cannot be EGL_DONT_CARE

---

 src/egl/main/eglconfig.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/src/egl/main/eglconfig.c b/src/egl/main/eglconfig.c
index 483d980..e1d53da 100644
--- a/src/egl/main/eglconfig.c
+++ b/src/egl/main/eglconfig.c
@@ -529,8 +529,9 @@ _eglParseConfigAttribList(_EGLConfig *conf, _EGLDisplay *dpy,
    if (!_eglValidateConfig(conf, EGL_TRUE))
       return EGL_FALSE;
 
-   /* the spec says that EGL_LEVEL cannot be EGL_DONT_CARE */
-   if (conf->Level == EGL_DONT_CARE)
+   /* EGL_LEVEL and EGL_MATCH_NATIVE_PIXMAP cannot be EGL_DONT_CARE */
+   if (conf->Level == EGL_DONT_CARE ||
+       conf->MatchNativePixmap == EGL_DONT_CARE)
       return EGL_FALSE;
 
    /* ignore other attributes when EGL_CONFIG_ID is given */




More information about the mesa-commit mailing list